@@ -4,5 +4,5 @@ declair
 Package for declaratively defining hyperparameter search experiments.
 """
 
-from .helpers import call
+from .helpers import manual
 from .env import Environment
