@@ -1,7 +1,7 @@
 DEF_KEY_EXECUTE_TIME = 'execute_time'
-DEF_KEY_MODE = 'mode'
-DEF_KEY_ENV_PARAMS = 'env_params'
 DEF_KEY_TYPE = 'type'
+DEF_KEY_ENV_PARAMS = 'env_params'
+DEF_KEY_SEARCH_MODE = 'mode'
 DEF_KEY_SEARCH_INFO = 'search_info'
 DEF_KEY_EXECUTE_FUNCTION = 'execute_function'
 DEF_KEY_CLEANUP_FUNCTION = 'cleanup_function'
@@ -13,9 +13,9 @@ DEF_KEY_PARAMS = 'params'
 DEF_KEY_STATIC_PARAMS = 'static_params'
 DEF_KEY_SEARCH_PARAMS = 'search_params'
 
-DEF_MODE_RUN = 'run'
-DEF_MODE_SEARCH = 'search'
-DEF_MODE_EXTEND = 'extend'
+DEF_TYPE_RUN = 'run'
+DEF_TYPE_SEARCH = 'search'
+DEF_TYPE_EXTEND = 'extend'
 
 DEF_STORED_RUN_CONFIG_NAME = 'declair_format_config.json'
 DEF_STORED_SEARCH_CONFIG_NAME = 'declair_format_search_config.json'
