@@ -5,7 +5,7 @@ experiment definition to expand upon some other experiment definition.
 from pathlib import Path
 
 from ..const import (DEF_KEY_EXTEND_PARENT,
-                     DEF_MODE_RUN, DEF_MODE_SEARCH, DEF_MODE_EXTEND)
+                     DEF_TYPE_RUN, DEF_TYPE_SEARCH, DEF_TYPE_EXTEND)
 from ..exception import InvalidConfigException
 from .insertion import _extend_from_file
 
@@ -19,4 +19,4 @@ def execute_extend(dict_, env, final_execute_func, filepath):
         filepath = str(filepath)
     extended_dict = _extend_from_file(dict_, dict_[DEF_KEY_EXTEND_PARENT],
                                       filepath)
-    final_execute_func(extended_dict, env)
+    return final_execute_func(extended_dict, env)
