@@ -1,4 +1,5 @@
 from ..exception import EnvironmentException, InvalidConfigException
+from ..env import _get_nested_key
 
 from .insertion import make_insert_func_recursive
 
@@ -28,7 +29,7 @@ def insert_env(obj, env):
                     raise
         elif isinstance(key, list) or isinstance(key, tuple):
             try:
-                return env.get_nested_key(key)
+                return env[key]
             except KeyError:
                 if 'default' in obj:
                     return obj['default']
