@@ -106,6 +106,8 @@ def hyperopt_search_space(obj, root='root'):
                 out_list.append(hyperopt_search_space(item, root='{}[{}]'.format(root, num)))
             else:
                 out_list.append(item)
+        if len(out_list) == 0:
+            raise InvalidConfigException('List of choices in search definition needs to contain at least one element: Check configuration for empty lists.')
         return hp.choice(root, out_list)
     elif type(obj) == dict:
         if unsearchable_run_entry(obj):
@@ -251,7 +253,7 @@ def execute_hyperopt_search(config, env):
     if not opt_params:
         raise InvalidConfigException("Please provide search_params.optimize in the experiment definition")
     # FIXME: Document best_so_far tracking
-    best_so_far_to_remember = config.get('search_params', {}).get('best_so_far_to_remember', 1)
+    best_so_far_to_remember = config.get('search_params', {}).get('best_so_far_to_remember', 0)
     best_so_far = {'__to_remember__': best_so_far_to_remember}
     opt_type = opt_params.get('type')
     if opt_type is None:
