@@ -1,5 +1,6 @@
 
 import os
+from tempfile import gettempdir
 
 # Functions for checking error handling
 def sample_valid_execute_function(params):
@@ -15,7 +16,7 @@ def sample_possibly_crashing_function(params):
 
 
 # Functions for checking if cleanup works
-_TEST_FILE_PATH = '.test_temporary_file'
+_TEST_FILE_PATH = os.path.join(gettempdir(), '.declair_tmp_file_for_experiment_cleanup_tests')
 def _make_environment_dirty():
     with open(_TEST_FILE_PATH, 'w') as file_:
         file_.write("A very dirty string")
